@@ -725,7 +725,9 @@ def _bqschema_to_nullsafe_dtypes(schema_fields):
         "GEOMETRY": "object",
         "RECORD": "object",
         "STRING": "object",
-        "TIME": "datetime64[ns]",
+        # datetime.time objects cannot be case to datetime64.
+        # https://github.com/pydata/pandas-gbq/issues/328
+        "TIME": "object",
         # pandas doesn't support timezone-aware dtype in DataFrame/Series
         # constructors. It's more idiomatic to localize after construction.
         # https://github.com/pandas-dev/pandas/issues/25843
@@ -1238,7 +1240,7 @@ def _generate_bq_schema(df, default_type="STRING"):
     issues in the default schema generation. Now that individual columns can
     be overridden: https://github.com/pydata/pandas-gbq/issues/218, this
     method can be removed after there is time to migrate away from this
-    method. """
+    method."""
     from pandas_gbq import schema
 
     return schema.generate_bq_schema(df, default_type=default_type)
@@ -1264,7 +1266,7 @@ class _Table(GbqConnector):
         )
 
     def exists(self, table_id):
-        """ Check if a table exists in Google BigQuery
+        """Check if a table exists in Google BigQuery
 
         Parameters
         ----------
@@ -1288,7 +1290,7 @@ class _Table(GbqConnector):
             self.process_http_error(ex)
 
     def create(self, table_id, schema):
-        """ Create a table in Google BigQuery given a table and schema
+        """Create a table in Google BigQuery given a table and schema
 
         Parameters
         ----------
@@ -1330,7 +1332,7 @@ class _Table(GbqConnector):
             self.process_http_error(ex)
 
     def delete(self, table_id):
-        """ Delete a table in Google BigQuery
+        """Delete a table in Google BigQuery
 
         Parameters
         ----------
@@ -1370,7 +1372,7 @@ class _Dataset(GbqConnector):
         )
 
     def exists(self, dataset_id):
-        """ Check if a dataset exists in Google BigQuery
+        """Check if a dataset exists in Google BigQuery
 
         Parameters
         ----------
@@ -1393,7 +1395,7 @@ class _Dataset(GbqConnector):
             self.process_http_error(ex)
 
     def create(self, dataset_id):
-        """ Create a dataset in Google BigQuery
+        """Create a dataset in Google BigQuery
 
         Parameters
         ----------
